/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hugegraph.api;

import org.junit.Test;

import jakarta.ws.rs.core.Response;

public class SchemaApiTest extends BaseApiTest {

    private static final String PATH = "/graphspaces/DEFAULT/graphs/hugegraph/schema";

    @Test
    public void testGet() {
        Response r = client().get(PATH);
        String content = assertResponseStatus(200, r);

        assertJsonContains(content, "propertykeys");
        assertJsonContains(content, "vertexlabels");
        assertJsonContains(content, "edgelabels");
        assertJsonContains(content, "indexlabels");
    }
}
